==> openshift-model-monitoring-6.9.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackActionFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SlackActionFluent<A extends SlackActionFluent<A>> extends BaseFluent<A>{
  public SlackActionFluent() {
  }
  
  public SlackActionFluent(SlackAction instance) {
    this.copyInstance(instance);
  }
  private SlackConfirmationFieldBuilder confirm;
  private String name;
  private String style;
  private String text;
  private String type;
  private String url;
  private String value;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SlackAction instance) {
    instance = (instance != null ? instance : new SlackAction());
    if (instance != null) {
          this.withConfirm(instance.getConfirm());
          this.withName(instance.getName());
          this.withStyle(instance.getStyle());
          this.withText(instance.getText());
          this.withType(instance.getType());
          this.withUrl(instance.getUrl());
          this.withValue(instance.getValue());
          this.withConfirm(instance.getConfirm());
          this.withName(instance.getName());
          this.withStyle(instance.getStyle());
          this.withText(instance.getText());
          this.withType(instance.getType());
          this.withUrl(instance.getUrl());
          this.withValue(instance.getValue());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public SlackConfirmationField buildConfirm() {
    return this.confirm != null ? this.confirm.build() : null;
  }
  
  public A withConfirm(SlackConfirmationField confirm) {
    this._visitables.remove(this.confirm);
    if (confirm != null) {
        this.confirm = new SlackConfirmationFieldBuilder(confirm);
        this._visitables.get("confirm").add(this.confirm);
    } else {
        this.confirm = null;
        this._visitables.get("confirm").remove(this.confirm);
    }
    return (A) this;
  }
  
  public boolean hasConfirm() {
    return this.confirm != null;
  }
  
  public A withNewConfirm(String dismissText,String okText,String text,String title) {
    return (A)withConfirm(new SlackConfirmationField(dismissText, okText, text, title));
  }
  
  public ConfirmNested<A> withNewConfirm() {
    return new ConfirmNested(null);
  }
  
  public ConfirmNested<A> withNewConfirmLike(SlackConfirmationField item) {
    return new ConfirmNested(item);
  }
  
  public ConfirmNested<A> editConfirm() {
    return withNewConfirmLike(java.util.Optional.ofNullable(buildConfirm()).orElse(null));
  }
  
  public ConfirmNested<A> editOrNewConfirm() {
    return withNewConfirmLike(java.util.Optional.ofNullable(buildConfirm()).orElse(new SlackConfirmationFieldBuilder().build()));
  }
  
  public ConfirmNested<A> editOrNewConfirmLike(SlackConfirmationField item) {
    return withNewConfirmLike(java.util.Optional.ofNullable(buildConfirm()).orElse(item));
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getStyle() {
    return this.style;
  }
  
  public A withStyle(String style) {
    this.style = style;
    return (A) this;
  }
  
  public boolean hasStyle() {
    return this.style != null;
  }
  
  public String getText() {
    return this.text;
  }
  
  public A withText(String text) {
    this.text = text;
    return (A) this;
  }
  
  public boolean hasText() {
    return this.text != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url = url;
    return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value = value;
    return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SlackActionFluent that = (SlackActionFluent) o;
    if (!java.util.Objects.equals(confirm, that.confirm)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(style, that.style)) return false;
    if (!java.util.Objects.equals(text, that.text)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(url, that.url)) return false;
    if (!java.util.Objects.equals(value, that.value)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(confirm,  name,  style,  text,  type,  url,  value,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (confirm != null) { sb.append("confirm:"); sb.append(confirm + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (style != null) { sb.append("style:"); sb.append(style + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConfirmNested<N> extends SlackConfirmationFieldFluent<ConfirmNested<N>> implements Nested<N>{
    ConfirmNested(SlackConfirmationField item) {
      this.builder = new SlackConfirmationFieldBuilder(this, item);
    }
    SlackConfirmationFieldBuilder builder;
    
    public N and() {
      return (N) SlackActionFluent.this.withConfirm(builder.build());
    }
    
    public N endConfirm() {
      return and();
    }
    
  
  }

}

==> openshift-model-monitoring-6.13.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackActionFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SlackActionFluent<A extends SlackActionFluent<A>> extends BaseFluent<A>{
  public SlackActionFluent() {
  }
  
  public SlackActionFluent(SlackAction instance) {
    this.copyInstance(instance);
  }
  private SlackConfirmationFieldBuilder confirm;
  private String name;
  private String style;
  private String text;
  private String type;
  private String url;
  private String value;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SlackAction instance) {
    instance = (instance != null ? instance : new SlackAction());
    if (instance != null) {
          this.withConfirm(instance.getConfirm());
          this.withName(instance.getName());
          this.withStyle(instance.getStyle());
          this.withText(instance.getText());
          this.withType(instance.getType());
          this.withUrl(instance.getUrl());
          this.withValue(instance.getValue());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public SlackConfirmationField buildConfirm() {
    return this.confirm != null ? this.confirm.build() : null;
  }
  
  public A withConfirm(SlackConfirmationField confirm) {
    this._visitables.remove("confirm");
    if (confirm != null) {
        this.confirm = new SlackConfirmationFieldBuilder(confirm);
        this._visitables.get("confirm").add(this.confirm);
    } else {
        this.confirm = null;
        this._visitables.get("confirm").remove(this.confirm);
    }
    return (A) this;
  }
  
  public boolean hasConfirm() {
    return this.confirm != null;
  }
  
  public A withNewConfirm(String dismissText,String okText,String text,String title) {
    return (A)withConfirm(new SlackConfirmationField(dismissText, okText, text, title));
  }
  
  public ConfirmNested<A> withNewConfirm() {
    return new ConfirmNested(null);
  }
  
  public ConfirmNested<A> withNewConfirmLike(SlackConfirmationField item) {
    return new ConfirmNested(item);
  }
  
  public ConfirmNested<A> editConfirm() {
    return withNewConfirmLike(java.util.Optional.ofNullable(buildConfirm()).orElse(null));
  }
  
  public ConfirmNested<A> editOrNewConfirm() {
    return withNewConfirmLike(java.util.Optional.ofNullable(buildConfirm()).orElse(new SlackConfirmationFieldBuilder().build()));
  }
  
  public ConfirmNested<A> editOrNewConfirmLike(SlackConfirmationField item) {
    return withNewConfirmLike(java.util.Optional.ofNullable(buildConfirm()).orElse(item));
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getStyle() {
    return this.style;
  }
  
  public A withStyle(String style) {
    this.style = style;
    return (A) this;
  }
  
  public boolean hasStyle() {
    return this.style != null;
  }
  
  public String getText() {
    return this.text;
  }
  
  public A withText(String text) {
    this.text = text;
    return (A) this;
  }
  
  public boolean hasText() {
    return this.text != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url = url;
    return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value = value;
    return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SlackActionFluent that = (SlackActionFluent) o;
    if (!java.util.Objects.equals(confirm, that.confirm)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(style, that.style)) return false;
    if (!java.util.Objects.equals(text, that.text)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(url, that.url)) return false;
    if (!java.util.Objects.equals(value, that.value)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(confirm,  name,  style,  text,  type,  url,  value,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (confirm != null) { sb.append("confirm:"); sb.append(confirm + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (style != null) { sb.append("style:"); sb.append(style + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConfirmNested<N> extends SlackConfirmationFieldFluent<ConfirmNested<N>> implements Nested<N>{
    ConfirmNested(SlackConfirmationField item) {
      this.builder = new SlackConfirmationFieldBuilder(this, item);
    }
    SlackConfirmationFieldBuilder builder;
    
    public N and() {
      return (N) SlackActionFluent.this.withConfirm(builder.build());
    }
    
    public N endConfirm() {
      return and();
    }
    
  
  }

}
